Crate chive

Crate chive 

Structs

Chive
An in-memory archive of serialized data, which is simply a flat sequence of bytes that can be saved, sent, copied, loaded, and deserialized again at a different time and place.
ChiveIn
ChiveIn is used to serialize user-provided data in to a Chive instance.
ChiveOut
ChiveOut is used to deserialize data out of an existing Chive instance.
ChiveOutIterator
Iterator for reading values out of a serialized array in a Chive instance one value at a time.

Enums

PrimitiveType
Enum for the set of primitive fixed-size types that are supported
ValueType
Enum for set the of value types that are supported

Traits

Chivable
Trait for a user-defined type that can be serialized and deserialized into a Chive.